@@ -71,31 +71,3 @@ sub template_files {
 }
 
 1;
-
-=encoding utf8;
-
-=head1 NAME
-
-Cog::FileBrowser -- Sample App/WebApp Built on Cog Framework
-
-=head1 SYNOPSIS
-
-    > cog init Cog::FileBrowser
-    > cog update
-    > cog make
-    > cog start
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2011. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
